#!/bin/bash
## usage ./plot-histograms <path-to-rivet> [<output-dir>]

if test -z "$1"; then
  RIVET=""
else
  RIVET=$1
fi

if test -f ${RIVET}/rivetenv.sh; then
  source ${RIVET}/rivetenv.sh
  export PATH=$PWD:$PATH
else
  echo "Please give path to Rivet installation"
  echo 'usage ./plot-histograms <path-to-rivet> [<output-dir>]'
  exit
fi

if test -z "$2"; then
  PLOTDIR="plots"
else
  PLOTDIR=$2
fi

echo "Plotting the Les Houches study's histograms to" ${PWD}/${PLOTDIR}

# copy needed to plot central values on top of overlapping bands
for i in "hej" "amcatnlo" "powhegbox" "pythia8" "sherpa";
do
  cp ${i}.aida ${i}-copy.aida
done

rivet-mkhtml -o $PLOTDIR -m MC_HDIJETS_LESHOUCHES \
  powhegbox.aida:'Title=\textsc{PowhegBox}':LineColor=black:LineStyle=solid:LineWidth=1.5pt:ErrorBands=1:ErrorBandColor=yellow:ErrorBandOpacity=1:LegendOrder=2:ErrorType=env \
  amcatnlo.aida:'Title=a\textsc{Mc@Nlo}':'LineColor={[rgb]{0.12,0.57,0.14}}':LineStyle=dashed:LineWidth=1.5pt:ErrorBands=1:ErrorBandColor=green:ErrorBandOpacity=0.2:LegendOrder=1:ErrorType=env \
  pythia8.aida:'Title=\textsc{Pythia}~8':'LineColor=pink!50!black':LineStyle=dashdotted:LineWidth=1.5pt:ErrorBands=1:ErrorBandColor=pink:ErrorBandOpacity=0.5:LegendOrder=3:ErrorType=env \
  sherpa.aida:'Title=\textsc{Sherpa}':'LineColor=orange!30!black':LineStyle=dashed:'LineDash=3pt 3pt 0.8pt 3pt 0.8pt 3pt 0.8pt 3pt':LineWidth=1.5pt:ErrorBands=1:ErrorBandColor=orange:ErrorBandOpacity=0.4:LegendOrder=4:ErrorType=env \
  hej.aida:'Title=\textsc{Hej}':LineColor=blue:LineStyle=dotted:LineWidth=1.5pt:ErrorBands=1:ErrorBandColor=blue:ErrorBandOpacity=0.2:LegendOrder=0:ErrorType=env \
  powhegbox-copy.aida:'Title=':LineColor=black:LineStyle=solid:LineWidth=1.5pt \
  amcatnlo-copy.aida:'Title=':'LineColor={[rgb]{0.12,0.57,0.14}}':LineStyle=dashed:LineWidth=1.5pt \
  pythia8-copy.aida:'Title=':'LineColor=pink!50!black':LineStyle=dashdotted:LineWidth=1.5pt \
  sherpa-copy.aida:'Title=':'LineColor=orange!30!black':LineStyle=dashed:'LineDash=3pt 3pt 0.8pt 3pt 0.8pt 3pt 0.8pt 3pt':LineWidth=1.5pt \
  hej-copy.aida:'Title=':LineColor=blue:LineStyle=dotted:LineWidth=1.5pt

# remove copies again
for i in "hej" "amcatnlo" "powhegbox" "pythia8" "sherpa";
do
  rm ${i}-copy.aida
done
